==> auto-ui-2.4.55.tgz: package/es/input/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import CloseIcon from '../icon/close';
import './style/index.scss';
var Input = /** @class */ (function (_super) {
    __extends(Input, _super);
    function Input(props) {
        var _this = _super.call(this, props) || this;
        // 劫持onBlur事件，解决input失去焦点时页面卡在半当中的情况
        _this.onBlur = function (evt) {
            var _a = _this.props, multi = _a.multi, inputProps = _a.inputProps, textareaProps = _a.textareaProps;
            evt.persist();
            if (multi && textareaProps && textareaProps.onBlur) {
                textareaProps.onBlur(evt);
            }
            else if (inputProps && inputProps.onBlur) {
                inputProps.onBlur(evt);
            }
            setTimeout(function () {
                _this.setState({
                    isFocus: false,
                });
            }, 0);
            setTimeout(function () {
                var ele = evt.target;
                if (ele) {
                    ;
                    ele.scrollIntoViewIfNeeded(false);
                }
            }, 300);
        };
        // 模拟onChange变化，将e.target.value赋值为空，外部接收的是ChangeEventHandler
        _this.onInputClear = function (e) {
            var _a = _this.props, onChange = _a.onChange, inputProps = _a.inputProps, textareaProps = _a.textareaProps, multi = _a.multi;
            var props = multi ? textareaProps : inputProps;
            e.target = __assign({ value: '' }, props);
            onChange && onChange(e);
        };
        // 劫持onFocus事件，当focus时，标记focus用于显示clear按钮
        _this.onFocus = function (e) {
            var _a = _this.props, multi = _a.multi, inputProps = _a.inputProps, textareaProps = _a.textareaProps;
            e.persist();
            if (multi && textareaProps && textareaProps.onFocus) {
                textareaProps.onFocus(e);
            }
            else if (inputProps && inputProps.onFocus) {
                inputProps.onFocus(e);
            }
            _this.setState({
                isFocus: true,
            });
        };
        _this.state = {
            isFocus: false,
        };
        return _this;
    }
    Input.prototype.render = function () {
        var _a = this.props, type = _a.type, className = _a.className, addonBefore = _a.addonBefore, addonAfter = _a.addonAfter, error = _a.error, multi = _a.multi, disabled = _a.disabled, value = _a.value, capsule = _a.capsule, onChange = _a.onChange, onReset = _a.onReset, placeholder = _a.placeholder, mini = _a.mini, inputProps = _a.inputProps, textareaProps = _a.textareaProps, allowClear = _a.allowClear, otherProps = __rest(_a, ["type", "className", "addonBefore", "addonAfter", "error", "multi", "disabled", "value", "capsule", "onChange", "onReset", "placeholder", "mini", "inputProps", "textareaProps", "allowClear"]);
        var composeClassName = cn('x-input', {
            'x-input--error': error,
            'x-input--multi': multi,
            'x-input--disabled': disabled,
            'x-input--mini': mini,
            'x-input--capsule': capsule,
            'x-input--clear': allowClear,
        }, className);
        if (multi) {
            return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
                !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
                React.createElement("textarea", __assign({ disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange }, textareaProps, { onBlur: this.onBlur, onFocus: this.onFocus })),
                allowClear && value && this.state.isFocus && (React.createElement("div", { className: "x-input__iconclear", onClick: this.onInputClear },
                    React.createElement("span", null,
                        React.createElement(CloseIcon, null)))),
                !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
        }
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
            !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
            React.createElement("input", __assign({ disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange, type: type || 'text' }, inputProps, { onBlur: this.onBlur, onFocus: this.onFocus })),
            allowClear && value && this.state.isFocus && (React.createElement("div", { className: "x-input__iconclear", onClick: this.onInputClear },
                React.createElement("span", null,
                    React.createElement(CloseIcon, null)))),
            !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
    };
    return Input;
}(React.PureComponent));
export default Input;

==> auto-ui-2.4.63.tgz: package/es/input/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import CloseIcon from '../icon/close';
import './style/index.scss';
var Input = /** @class */ (function (_super) {
    __extends(Input, _super);
    function Input(props) {
        var _this = _super.call(this, props) || this;
        // 劫持onBlur事件，解决input失去焦点时页面卡在半当中的情况
        _this.onBlur = function (evt) {
            var _a = _this.props, multi = _a.multi, inputProps = _a.inputProps, textareaProps = _a.textareaProps;
            evt.persist();
            if (multi && textareaProps && textareaProps.onBlur) {
                textareaProps.onBlur(evt);
            }
            else if (inputProps && inputProps.onBlur) {
                inputProps.onBlur(evt);
            }
            setTimeout(function () {
                _this.setState({
                    isFocus: false,
                });
            }, 0);
            setTimeout(function () {
                var ele = evt.target;
                if (ele) {
                    ;
                    ele.scrollIntoViewIfNeeded(false);
                }
            }, 300);
        };
        // 模拟onChange变化，将e.target.value赋值为空，外部接收的是ChangeEventHandler
        _this.onInputClear = function (e) {
            var _a = _this.props, onChange = _a.onChange, inputProps = _a.inputProps, textareaProps = _a.textareaProps, multi = _a.multi;
            var props = multi ? textareaProps : inputProps;
            e.target = __assign({ value: '' }, props);
            onChange && onChange(e);
        };
        // 劫持onFocus事件，当focus时，标记focus用于显示clear按钮
        _this.onFocus = function (e) {
            var _a = _this.props, multi = _a.multi, inputProps = _a.inputProps, textareaProps = _a.textareaProps;
            e.persist();
            if (multi && textareaProps && textareaProps.onFocus) {
                textareaProps.onFocus(e);
            }
            else if (inputProps && inputProps.onFocus) {
                inputProps.onFocus(e);
            }
            _this.setState({
                isFocus: true,
            });
        };
        _this.state = {
            isFocus: false,
        };
        return _this;
    }
    Input.prototype.render = function () {
        var _a = this.props, type = _a.type, className = _a.className, addonBefore = _a.addonBefore, addonAfter = _a.addonAfter, error = _a.error, multi = _a.multi, disabled = _a.disabled, value = _a.value, capsule = _a.capsule, onChange = _a.onChange, onReset = _a.onReset, placeholder = _a.placeholder, mini = _a.mini, inputProps = _a.inputProps, textareaProps = _a.textareaProps, allowClear = _a.allowClear, otherProps = __rest(_a, ["type", "className", "addonBefore", "addonAfter", "error", "multi", "disabled", "value", "capsule", "onChange", "onReset", "placeholder", "mini", "inputProps", "textareaProps", "allowClear"]);
        var composeClassName = cn('x-input', {
            'x-input--error': error,
            'x-input--multi': multi,
            'x-input--disabled': disabled,
            'x-input--mini': mini,
            'x-input--capsule': capsule,
            'x-input--clear': allowClear,
        }, className);
        if (multi) {
            return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
                !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
                React.createElement("textarea", __assign({ disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange }, textareaProps, { onBlur: this.onBlur, onFocus: this.onFocus })),
                allowClear && value && this.state.isFocus && (React.createElement("div", { className: "x-input__iconclear", onClick: this.onInputClear },
                    React.createElement("span", null,
                        React.createElement(CloseIcon, null)))),
                !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
        }
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
            !!addonBefore && React.createElement("div", { className: "x-input__addon-before" }, addonBefore),
            React.createElement("input", __assign({ disabled: disabled, className: "x-input__ipt", value: value, placeholder: placeholder, onChange: onChange, type: type || 'text' }, inputProps, { onBlur: this.onBlur, onFocus: this.onFocus })),
            allowClear && value && this.state.isFocus && (React.createElement("div", { className: "x-input__iconclear", onClick: this.onInputClear },
                React.createElement("span", null,
                    React.createElement(CloseIcon, null)))),
            !!addonAfter && React.createElement("div", { className: "x-input__addon-after" }, addonAfter)));
    };
    return Input;
}(React.PureComponent));
export default Input;
